{
    "$graph": [
        {
            "class": "Workflow",
            "label": "bam_readcount workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_readcount.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#bam_readcount.cwl/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#bam_readcount.cwl/min_mapping_quality"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#bam_readcount.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "id": "#bam_readcount.cwl/sample"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bam_readcount.cwl/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bam_readcount.cwl_2",
                    "in": [
                        {
                            "source": "#bam_readcount.cwl/bam",
                            "id": "#bam_readcount.cwl/bam_readcount/bam"
                        },
                        {
                            "source": "#bam_readcount.cwl/min_base_quality",
                            "id": "#bam_readcount.cwl/bam_readcount/min_base_quality"
                        },
                        {
                            "source": "#bam_readcount.cwl/min_mapping_quality",
                            "id": "#bam_readcount.cwl/bam_readcount/min_mapping_quality"
                        },
                        {
                            "source": "#bam_readcount.cwl/reference_fasta",
                            "id": "#bam_readcount.cwl/bam_readcount/reference_fasta"
                        },
                        {
                            "source": "#bam_readcount.cwl/sample",
                            "id": "#bam_readcount.cwl/bam_readcount/sample"
                        },
                        {
                            "source": "#bam_readcount.cwl/decompose_variants/decomposed_vcf",
                            "id": "#bam_readcount.cwl/bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#bam_readcount.cwl/bam_readcount/snv_bam_readcount_tsv",
                        "#bam_readcount.cwl/bam_readcount/indel_bam_readcount_tsv"
                    ],
                    "id": "#bam_readcount.cwl/bam_readcount"
                },
                {
                    "run": "#vt_decompose.cwl",
                    "in": [
                        {
                            "source": "#bam_readcount.cwl/normalize_variants/normalized_vcf",
                            "id": "#bam_readcount.cwl/decompose_variants/vcf"
                        }
                    ],
                    "out": [
                        "#bam_readcount.cwl/decompose_variants/decomposed_vcf"
                    ],
                    "id": "#bam_readcount.cwl/decompose_variants"
                },
                {
                    "run": "#normalize_variants.cwl",
                    "in": [
                        {
                            "source": "#bam_readcount.cwl/reference_fasta",
                            "id": "#bam_readcount.cwl/normalize_variants/reference"
                        },
                        {
                            "source": "#bam_readcount.cwl/vcf",
                            "id": "#bam_readcount.cwl/normalize_variants/vcf"
                        }
                    ],
                    "out": [
                        "#bam_readcount.cwl/normalize_variants/normalized_vcf"
                    ],
                    "id": "#bam_readcount.cwl/normalize_variants"
                }
            ],
            "id": "#bam_readcount.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bam_readcount.cwl/bam_readcount/indel_bam_readcount_tsv",
                    "id": "#bam_readcount.cwl/indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#bam_readcount.cwl/decompose_variants/decomposed_vcf",
                    "id": "#bam_readcount.cwl/normalized_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#bam_readcount.cwl/bam_readcount/snv_bam_readcount_tsv",
                    "id": "#bam_readcount.cwl/snv_bam_readcount_tsv"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "Workflow to run pVACseq from detect_variants and rnaseq pipeline outputs",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/additional_report_columns/sample_name"
                            ]
                        }
                    ],
                    "id": "#main/additional_report_columns"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/allele_specific_binding_thresholds"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/alleles"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/binding_threshold"
                },
                {
                    "type": "File",
                    "id": "#main/detect_variants_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/downstream_sequence_length"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "id": "#main/epitope_lengths"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/exclude_nas"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/expn_val"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "kallisto",
                    "id": "#main/expression_tool"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/fasta_size"
                },
                {
                    "type": "File",
                    "id": "#main/gene_expression_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/maximum_transcript_support_level/1",
                                "#main/maximum_transcript_support_level/2",
                                "#main/maximum_transcript_support_level/3",
                                "#main/maximum_transcript_support_level/4",
                                "#main/maximum_transcript_support_level/5"
                            ]
                        }
                    ],
                    "id": "#main/maximum_transcript_support_level"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/minimum_fold_change"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/n_threads"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/net_chop_method/cterm",
                                "#main/net_chop_method/20s"
                            ]
                        }
                    ],
                    "id": "#main/net_chop_method"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/net_chop_threshold"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/netmhc_stab"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/normal_cov"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "NORMAL",
                    "id": "#main/normal_sample_name"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/normal_vaf"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/peptide_sequence_length"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/phased_proximal_variants_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/prediction_algorithms"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/readcount_minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/readcount_minimum_mapping_quality"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference_fasta"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/rnaseq_bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TUMOR",
                    "id": "#main/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/tdna_cov"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/tdna_vaf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/top_score_metric/lowest",
                                "#main/top_score_metric/median"
                            ]
                        }
                    ],
                    "id": "#main/top_score_metric"
                },
                {
                    "type": "File",
                    "id": "#main/transcript_expression_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/trna_cov"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#main/trna_vaf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT"
                    ],
                    "id": "#main/variants_to_table_fields"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "GT",
                        "AD",
                        "AF",
                        "DP",
                        "RAD",
                        "RAF",
                        "RDP",
                        "GX",
                        "TX"
                    ],
                    "id": "#main/variants_to_table_genotype_fields"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "HGVSc",
                        "HGVSp"
                    ],
                    "id": "#main/vep_to_table_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/add_vep_fields_to_table/annotated_variants_tsv",
                    "id": "#main/annotated_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/add_transcript_expression_data_to_vcf/annotated_expression_vcf",
                    "id": "#main/annotated_vcf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/pvacseq/combined_all_epitopes",
                    "id": "#main/combined_all_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/pvacseq/combined_filtered_epitopes",
                    "id": "#main/combined_filtered_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/pvacseq/combined_ranked_epitopes",
                    "id": "#main/combined_ranked_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/pvacseq/mhc_i_all_epitopes",
                    "id": "#main/mhc_i_all_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/pvacseq/mhc_i_filtered_epitopes",
                    "id": "#main/mhc_i_filtered_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/pvacseq/mhc_i_ranked_epitopes",
                    "id": "#main/mhc_i_ranked_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/pvacseq/mhc_ii_all_epitopes",
                    "id": "#main/mhc_ii_all_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/pvacseq/mhc_ii_filtered_epitopes",
                    "id": "#main/mhc_ii_filtered_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/pvacseq/mhc_ii_ranked_epitopes",
                    "id": "#main/mhc_ii_ranked_epitopes"
                }
            ],
            "steps": [
                {
                    "run": "#vcf_expression_annotator.cwl",
                    "in": [
                        {
                            "default": "gene",
                            "id": "#main/add_gene_expression_data_to_vcf/data_type"
                        },
                        {
                            "source": "#main/gene_expression_file",
                            "id": "#main/add_gene_expression_data_to_vcf/expression_file"
                        },
                        {
                            "source": "#main/expression_tool",
                            "id": "#main/add_gene_expression_data_to_vcf/expression_tool"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/add_gene_expression_data_to_vcf/sample_name"
                        },
                        {
                            "source": "#main/add_tumor_rna_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#main/add_gene_expression_data_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_gene_expression_data_to_vcf/annotated_expression_vcf"
                    ],
                    "id": "#main/add_gene_expression_data_to_vcf"
                },
                {
                    "run": "#vcf_expression_annotator.cwl",
                    "in": [
                        {
                            "default": "transcript",
                            "id": "#main/add_transcript_expression_data_to_vcf/data_type"
                        },
                        {
                            "source": "#main/transcript_expression_file",
                            "id": "#main/add_transcript_expression_data_to_vcf/expression_file"
                        },
                        {
                            "source": "#main/expression_tool",
                            "id": "#main/add_transcript_expression_data_to_vcf/expression_tool"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/add_transcript_expression_data_to_vcf/sample_name"
                        },
                        {
                            "source": "#main/add_gene_expression_data_to_vcf/annotated_expression_vcf",
                            "id": "#main/add_transcript_expression_data_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_transcript_expression_data_to_vcf/annotated_expression_vcf"
                    ],
                    "id": "#main/add_transcript_expression_data_to_vcf"
                },
                {
                    "run": "#vcf_readcount_annotator.cwl",
                    "in": [
                        {
                            "default": "RNA",
                            "id": "#main/add_tumor_rna_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#main/tumor_rna_bam_readcount/indel_bam_readcount_tsv",
                            "id": "#main/add_tumor_rna_bam_readcount_to_vcf/indel_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/add_tumor_rna_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "source": "#main/tumor_rna_bam_readcount/snv_bam_readcount_tsv",
                            "id": "#main/add_tumor_rna_bam_readcount_to_vcf/snv_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/tumor_rna_bam_readcount/normalized_vcf",
                            "id": "#main/add_tumor_rna_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_tumor_rna_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#main/add_tumor_rna_bam_readcount_to_vcf"
                },
                {
                    "run": "#add_vep_fields_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table/variants_tsv",
                            "id": "#main/add_vep_fields_to_table/tsv"
                        },
                        {
                            "source": "#main/index/indexed_vcf",
                            "id": "#main/add_vep_fields_to_table/vcf"
                        },
                        {
                            "source": "#main/vep_to_table_fields",
                            "id": "#main/add_vep_fields_to_table/vep_fields"
                        }
                    ],
                    "out": [
                        "#main/add_vep_fields_to_table/annotated_variants_tsv"
                    ],
                    "id": "#main/add_vep_fields_to_table"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/add_transcript_expression_data_to_vcf/annotated_expression_vcf",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                },
                {
                    "run": "#pvacseq.cwl",
                    "in": [
                        {
                            "source": "#main/additional_report_columns",
                            "id": "#main/pvacseq/additional_report_columns"
                        },
                        {
                            "source": "#main/alleles",
                            "id": "#main/pvacseq/alleles"
                        },
                        {
                            "source": "#main/downstream_sequence_length",
                            "id": "#main/pvacseq/downstream_sequence_length"
                        },
                        {
                            "source": "#main/epitope_lengths",
                            "id": "#main/pvacseq/epitope_lengths"
                        },
                        {
                            "source": "#main/exclude_nas",
                            "id": "#main/pvacseq/exclude_nas"
                        },
                        {
                            "source": "#main/expn_val",
                            "id": "#main/pvacseq/expn_val"
                        },
                        {
                            "source": "#main/fasta_size",
                            "id": "#main/pvacseq/fasta_size"
                        },
                        {
                            "source": "#main/index/indexed_vcf",
                            "id": "#main/pvacseq/input_vcf"
                        },
                        {
                            "source": "#main/maximum_transcript_support_level",
                            "id": "#main/pvacseq/maximum_transcript_support_level"
                        },
                        {
                            "source": "#main/minimum_fold_change",
                            "id": "#main/pvacseq/minimum_fold_change"
                        },
                        {
                            "source": "#main/n_threads",
                            "id": "#main/pvacseq/n_threads"
                        },
                        {
                            "source": "#main/net_chop_method",
                            "id": "#main/pvacseq/net_chop_method"
                        },
                        {
                            "source": "#main/net_chop_threshold",
                            "id": "#main/pvacseq/net_chop_threshold"
                        },
                        {
                            "source": "#main/netmhc_stab",
                            "id": "#main/pvacseq/netmhc_stab"
                        },
                        {
                            "source": "#main/normal_cov",
                            "id": "#main/pvacseq/normal_cov"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/pvacseq/normal_sample_name"
                        },
                        {
                            "source": "#main/normal_vaf",
                            "id": "#main/pvacseq/normal_vaf"
                        },
                        {
                            "source": "#main/peptide_sequence_length",
                            "id": "#main/pvacseq/peptide_sequence_length"
                        },
                        {
                            "source": "#main/phased_proximal_variants_vcf",
                            "id": "#main/pvacseq/phased_proximal_variants_vcf"
                        },
                        {
                            "source": "#main/prediction_algorithms",
                            "id": "#main/pvacseq/prediction_algorithms"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/pvacseq/sample_name"
                        },
                        {
                            "source": "#main/tdna_cov",
                            "id": "#main/pvacseq/tdna_cov"
                        },
                        {
                            "source": "#main/tdna_vaf",
                            "id": "#main/pvacseq/tdna_vaf"
                        },
                        {
                            "source": "#main/top_score_metric",
                            "id": "#main/pvacseq/top_score_metric"
                        },
                        {
                            "source": "#main/trna_cov",
                            "id": "#main/pvacseq/trna_cov"
                        },
                        {
                            "source": "#main/trna_vaf",
                            "id": "#main/pvacseq/trna_vaf"
                        }
                    ],
                    "out": [
                        "#main/pvacseq/mhc_i_all_epitopes",
                        "#main/pvacseq/mhc_i_filtered_epitopes",
                        "#main/pvacseq/mhc_i_ranked_epitopes",
                        "#main/pvacseq/mhc_ii_all_epitopes",
                        "#main/pvacseq/mhc_ii_filtered_epitopes",
                        "#main/pvacseq/mhc_ii_ranked_epitopes",
                        "#main/pvacseq/combined_all_epitopes",
                        "#main/pvacseq/combined_filtered_epitopes",
                        "#main/pvacseq/combined_ranked_epitopes"
                    ],
                    "id": "#main/pvacseq"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#main/rnaseq_bam",
                            "id": "#main/tumor_rna_bam_readcount/bam"
                        },
                        {
                            "source": "#main/readcount_minimum_base_quality",
                            "id": "#main/tumor_rna_bam_readcount/min_base_quality"
                        },
                        {
                            "source": "#main/readcount_minimum_mapping_quality",
                            "id": "#main/tumor_rna_bam_readcount/min_mapping_quality"
                        },
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/tumor_rna_bam_readcount/reference_fasta"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/tumor_rna_bam_readcount/sample"
                        },
                        {
                            "source": "#main/detect_variants_vcf",
                            "id": "#main/tumor_rna_bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#main/tumor_rna_bam_readcount/snv_bam_readcount_tsv",
                        "#main/tumor_rna_bam_readcount/indel_bam_readcount_tsv",
                        "#main/tumor_rna_bam_readcount/normalized_vcf"
                    ],
                    "id": "#main/tumor_rna_bam_readcount"
                },
                {
                    "run": "#variants_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table_fields",
                            "id": "#main/variants_to_table/fields"
                        },
                        {
                            "source": "#main/variants_to_table_genotype_fields",
                            "id": "#main/variants_to_table/genotype_fields"
                        },
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/variants_to_table/reference"
                        },
                        {
                            "source": "#main/index/indexed_vcf",
                            "id": "#main/variants_to_table/vcf"
                        }
                    ],
                    "out": [
                        "#main/variants_to_table/variants_tsv"
                    ],
                    "id": "#main/variants_to_table"
                }
            ],
            "id": "#main"
        },
        {
            "class": "Workflow",
            "label": "Add snv and indel bam-readcount files to a vcf",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl/data_type/DNA",
                                "#vcf_readcount_annotator.cwl/data_type/RNA"
                            ]
                        }
                    ],
                    "id": "#vcf_readcount_annotator.cwl/data_type"
                },
                {
                    "type": "File",
                    "id": "#vcf_readcount_annotator.cwl/indel_bam_readcount_tsv"
                },
                {
                    "type": "string",
                    "id": "#vcf_readcount_annotator.cwl/sample_name"
                },
                {
                    "type": "File",
                    "id": "#vcf_readcount_annotator.cwl/snv_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#vcf_readcount_annotator.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                    "id": "#vcf_readcount_annotator.cwl/annotated_bam_readcount_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#vcf_readcount_annotator.cwl_2",
                    "in": [
                        {
                            "source": "#vcf_readcount_annotator.cwl/indel_bam_readcount_tsv",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/data_type",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/sample_name",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "default": "indel",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/variant_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf"
                },
                {
                    "run": "#vcf_readcount_annotator.cwl_2",
                    "in": [
                        {
                            "source": "#vcf_readcount_annotator.cwl/snv_bam_readcount_tsv",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/data_type",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/sample_name",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "default": "snv",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/variant_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/vcf",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf"
                }
            ],
            "id": "#vcf_readcount_annotator.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add VEP annotation to report",
            "baseCommand": [
                "vep-annotation-reporter"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/vatools:3.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.prefix).annotated.tsv"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "variants",
                    "id": "#add_vep_fields_to_table.cwl/prefix"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#add_vep_fields_to_table.cwl/tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_vep_fields_to_table.cwl/vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "Consequence",
                        "SYMBOL",
                        "Feature",
                        "HGVSc",
                        "HGVSp"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_vep_fields_to_table.cwl/vep_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix).annotated.tsv"
                    },
                    "id": "#add_vep_fields_to_table.cwl/annotated_variants_tsv"
                }
            ],
            "id": "#add_vep_fields_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "run bam-readcount",
            "baseCommand": [
                "/usr/bin/python",
                "bam_readcount_helper.py"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bam_readcount_helper-cwl:1.1.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "bam_readcount_helper.py",
                            "entry": "#!/usr/bin/env python\n\nimport sys\nimport os\nfrom cyvcf2 import VCF\nimport tempfile\nimport csv\nfrom subprocess import Popen, PIPE\n\ndef generate_region_list(hash):\n    fh = tempfile.NamedTemporaryFile('w', delete=False)\n    writer = csv.writer(fh, delimiter='\\t')\n    for chr, positions in hash.items():\n        for pos in sorted(positions.keys()):\n            writer.writerow([chr, pos, pos])\n    fh.close()\n    return fh.name\n\ndef filter_sites_in_hash(region_list, bam_file, ref_fasta, prefixed_sample, output_dir, insertion_centric, map_qual, base_qual):\n    bam_readcount_cmd = ['/usr/bin/bam-readcount', '-f', ref_fasta, '-l', region_list, '-w', '0', '-b', str(base_qual), '-q', str(map_qual)]\n    if insertion_centric:\n        bam_readcount_cmd.append('-i')\n        output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_indel.tsv')\n    else:\n        output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_snv.tsv')\n    bam_readcount_cmd.append(bam_file)\n    execution = Popen(bam_readcount_cmd, stdout=PIPE, stderr=PIPE)\n    stdout, stderr = execution.communicate()\n    if execution.returncode == 0:\n        with open(output_file, 'wb') as output_fh:\n            output_fh.write(stdout)\n    else:\n        sys.exit(stderr)\n\n#initializing these with default values\nmin_base_qual = 20\nmin_mapping_qual = 0\n\nif len(sys.argv) == 7:\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir)= sys.argv\nelif len(sys.argv) == 8:\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir, min_base_qual)= sys.argv\nelif len(sys.argv) == 9: #elif instead of else for explicit safety\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir, min_base_qual, min_mapping_qual)= sys.argv\n\nif prefix == 'NOPREFIX':\n    prefixed_sample = sample\nelse:\n    prefixed_sample = '_'.join([prefix, sample])\n\nvcf_file = VCF(vcf_filename)\nsample_index = vcf_file.samples.index(sample)\n\nrc_for_indel = {}\nrc_for_snp   = {}\nfor variant in vcf_file:\n    ref = variant.REF\n    chr = variant.CHROM\n    start = variant.start\n    end = variant.end\n    pos = variant.POS\n    for var in  variant.ALT:\n        if len(ref) > 1 or len(var) > 1:\n            #it's an indel or mnp\n            if len(ref) == len(var) or (len(ref) > 1 and len(var) > 1):\n                sys.stderr.write(\"Complex variant or MNP will be skipped: %s\\t%s\\t%s\\t%s\\n\" % (chr, pos, ref , var))\n                continue\n            elif len(ref) > len(var):\n                #it's a deletion\n                pos += 1\n                unmodified_ref = ref\n                ref = unmodified_ref[1]\n                var = \"-%s\" % unmodified_ref[1:]\n            else:\n                #it's an insertion\n                var = \"+%s\" % var[1:]\n            if chr not in rc_for_indel:\n                rc_for_indel[chr] = {}\n            if pos not in rc_for_indel[chr]:\n                rc_for_indel[chr][pos] = {}\n            if ref not in rc_for_indel[chr][pos]:\n                rc_for_indel[chr][pos][ref] = {}\n            rc_for_indel[chr][pos][ref] = variant\n        else:\n            #it's a SNP\n            if chr not in rc_for_snp:\n                rc_for_snp[chr] = {}\n            if pos not in rc_for_snp[chr]:\n                rc_for_snp[chr][pos] = {}\n            if ref not in rc_for_snp[chr][pos]:\n                rc_for_snp[chr][pos][ref] = {}\n            rc_for_snp[chr][pos][ref] = variant\n\nif len(rc_for_snp.keys()) > 0:\n    region_file = generate_region_list(rc_for_snp)\n    filter_sites_in_hash(region_file, bam_file, ref_fasta, prefixed_sample, output_dir, False, min_mapping_qual, min_base_qual)\nelse:\n    output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_snv.tsv')\n    open(output_file, 'w').close()\n\nif len(rc_for_indel.keys()) > 0:\n    region_file = generate_region_list(rc_for_indel)\n    filter_sites_in_hash(region_file, bam_file, ref_fasta, prefixed_sample, output_dir, True, min_mapping_qual, min_base_qual)\nelse:\n    output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_indel.tsv')\n    open(output_file, 'w').close()\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -3
                }
            ],
            "stdout": "$(inputs.sample)_bam_readcount.tsv",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -5
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_readcount.cwl_2/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#bam_readcount.cwl_2/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#bam_readcount.cwl_2/min_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "NOPREFIX",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#bam_readcount.cwl_2/prefix"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": -6
                    },
                    "id": "#bam_readcount.cwl_2/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -7
                    },
                    "id": "#bam_readcount.cwl_2/sample"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -8
                    },
                    "id": "#bam_readcount.cwl_2/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    var name = \"_bam_readcount_indel.tsv\";\n    if (inputs.prefix.equals(\"NOPREFIX\")) {\n        name = inputs.sample + name;\n    }\n    else {\n        name = inputs.prefix + \"_\" + inputs.sample + name;\n    }\n    return name;\n}\n"
                    },
                    "id": "#bam_readcount.cwl_2/indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    var name = \"_bam_readcount_snv.tsv\";\n    if (inputs.prefix.equals(\"NOPREFIX\")) {\n        name = inputs.sample + name;\n    }\n    else {\n        name = inputs.prefix + \"_\" + inputs.sample + name;\n    }\n    return name;\n}\n"
                    },
                    "id": "#bam_readcount.cwl_2/snv_bam_readcount_tsv"
                }
            ],
            "id": "#bam_readcount.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Normalize variants",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "LeftAlignAndTrimVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/normalized.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#normalize_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#normalize_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "normalized.vcf.gz"
                    },
                    "id": "#normalize_variants.cwl/normalized_vcf"
                }
            ],
            "id": "#normalize_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "run pVACseq",
            "baseCommand": [
                "ln",
                "-s"
            ],
            "arguments": [
                {
                    "valueFrom": "$TMPDIR",
                    "shellQuote": false
                },
                "/tmp/pvacseq",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "export",
                "TMPDIR=/tmp/pvacseq",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/conda/bin/pvacseq",
                "run",
                "--iedb-install-directory",
                "/opt/iedb",
                "--pass-only",
                {
                    "position": 5,
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/pvactools:1.5.3"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": "$(inputs.n_threads)"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#pvacseq.cwl/additional_report_columns/sample_name"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "id": "#pvacseq.cwl/additional_report_columns"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--allele-specific-binding-thresholds"
                    },
                    "id": "#pvacseq.cwl/allele_specific_binding_thresholds"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "position": 3,
                        "itemSeparator": ",",
                        "separate": false,
                        "prefix": ""
                    },
                    "id": "#pvacseq.cwl/alleles"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "id": "#pvacseq.cwl/binding_threshold"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-d"
                    },
                    "id": "#pvacseq.cwl/downstream_sequence_length"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-e",
                        "itemSeparator": ",",
                        "separate": false
                    },
                    "id": "#pvacseq.cwl/epitope_lengths"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--exclude-NAs"
                    },
                    "id": "#pvacseq.cwl/exclude_nas"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--expn-val"
                    },
                    "id": "#pvacseq.cwl/expn_val"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#pvacseq.cwl/fasta_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#pvacseq.cwl/iedb_retries"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#pvacseq.cwl/input_vcf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-k"
                    },
                    "id": "#pvacseq.cwl/keep_tmp_files"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#pvacseq.cwl/maximum_transcript_support_level/1",
                                "#pvacseq.cwl/maximum_transcript_support_level/2",
                                "#pvacseq.cwl/maximum_transcript_support_level/3",
                                "#pvacseq.cwl/maximum_transcript_support_level/4",
                                "#pvacseq.cwl/maximum_transcript_support_level/5"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--maximum-transcript-support-level"
                    },
                    "id": "#pvacseq.cwl/maximum_transcript_support_level"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#pvacseq.cwl/minimum_fold_change"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--n-threads"
                    },
                    "default": 8,
                    "id": "#pvacseq.cwl/n_threads"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#pvacseq.cwl/net_chop_method/cterm",
                                "#pvacseq.cwl/net_chop_method/20s"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--net-chop-method"
                    },
                    "id": "#pvacseq.cwl/net_chop_method"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--net-chop-threshold"
                    },
                    "id": "#pvacseq.cwl/net_chop_threshold"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--netmhc-stab"
                    },
                    "id": "#pvacseq.cwl/netmhc_stab"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--normal-cov"
                    },
                    "id": "#pvacseq.cwl/normal_cov"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--normal-sample-name"
                    },
                    "id": "#pvacseq.cwl/normal_sample_name"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--normal-vaf"
                    },
                    "id": "#pvacseq.cwl/normal_vaf"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#pvacseq.cwl/peptide_sequence_length"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#pvacseq.cwl/phased_proximal_variants_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#pvacseq.cwl/prediction_algorithms"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#pvacseq.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--tdna-cov"
                    },
                    "id": "#pvacseq.cwl/tdna_cov"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--tdna-vaf"
                    },
                    "id": "#pvacseq.cwl/tdna_vaf"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#pvacseq.cwl/top_score_metric/lowest",
                                "#pvacseq.cwl/top_score_metric/median"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#pvacseq.cwl/top_score_metric"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--trna-cov"
                    },
                    "id": "#pvacseq.cwl/trna_cov"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--trna-vaf"
                    },
                    "id": "#pvacseq.cwl/trna_vaf"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "combined/$(inputs.sample_name).all_epitopes.tsv"
                    },
                    "id": "#pvacseq.cwl/combined_all_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "combined/$(inputs.sample_name).filtered.tsv"
                    },
                    "id": "#pvacseq.cwl/combined_filtered_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "combined/$(inputs.sample_name).filtered.condensed.ranked.tsv"
                    },
                    "id": "#pvacseq.cwl/combined_ranked_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "MHC_Class_I/$(inputs.sample_name).all_epitopes.tsv"
                    },
                    "id": "#pvacseq.cwl/mhc_i_all_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "MHC_Class_I/$(inputs.sample_name).filtered.tsv"
                    },
                    "id": "#pvacseq.cwl/mhc_i_filtered_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "MHC_Class_I/$(inputs.sample_name).filtered.condensed.ranked.tsv"
                    },
                    "id": "#pvacseq.cwl/mhc_i_ranked_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "MHC_Class_II/$(inputs.sample_name).all_epitopes.tsv"
                    },
                    "id": "#pvacseq.cwl/mhc_ii_all_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "MHC_Class_II/$(inputs.sample_name).filtered.tsv"
                    },
                    "id": "#pvacseq.cwl/mhc_ii_filtered_epitopes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "MHC_Class_II/$(inputs.sample_name).filtered.condensed.ranked.tsv"
                    },
                    "id": "#pvacseq.cwl/mhc_ii_ranked_epitopes"
                }
            ],
            "id": "#pvacseq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantsToTable"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "--allowMissingData",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/variants.tsv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-F"
                        }
                    },
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT",
                        "set"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#variants_to_table.cwl/fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GF"
                        }
                    },
                    "default": [
                        "GT",
                        "AD",
                        "DP",
                        "AF"
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#variants_to_table.cwl/genotype_fields"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#variants_to_table.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#variants_to_table.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.tsv"
                    },
                    "id": "#variants_to_table.cwl/variants_tsv"
                }
            ],
            "id": "#variants_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add expression info to vcf",
            "baseCommand": [
                "vcf-expression-annotator"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/vatools:3.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.expression.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#vcf_expression_annotator.cwl/data_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#vcf_expression_annotator.cwl/expression_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#vcf_expression_annotator.cwl/expression_tool"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#vcf_expression_annotator.cwl/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#vcf_expression_annotator.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.expression.vcf.gz"
                    },
                    "id": "#vcf_expression_annotator.cwl/annotated_expression_vcf"
                }
            ],
            "id": "#vcf_expression_annotator.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add bam_readcount info to vcf",
            "baseCommand": [
                "vcf-readcount-annotator"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/vatools:3.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.bam_readcount.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/bam_readcount_tsv"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl_2/data_type/DNA",
                                "#vcf_readcount_annotator.cwl_2/data_type/RNA"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/data_type"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/sample_name"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl_2/variant_type/snv",
                                "#vcf_readcount_annotator.cwl_2/variant_type/indel",
                                "#vcf_readcount_annotator.cwl_2/variant_type/all"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/variant_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.bam_readcount.vcf.gz"
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/annotated_bam_readcount_vcf"
                }
            ],
            "id": "#vcf_readcount_annotator.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "run vt decompose",
            "baseCommand": [
                "vt",
                "decompose"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/vt:0.57721--hf74b74d_1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-s",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/decomposed.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#vt_decompose.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "decomposed.vcf.gz"
                    },
                    "id": "#vt_decompose.cwl/decomposed_vcf"
                }
            ],
            "id": "#vt_decompose.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
